==> mozilla-source-1.3.tar.bz2: mozilla/widget/src/os2/resource.h <==
/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 *
 * The Original Code is the Mozilla OS/2 libraries.
 *
 * The Initial Developer of the Original Code is John Fairhurst,
 * <john_fairhurst@iname.com>.  Portions created by John Fairhurst are
 * Copyright (C) 1999 John Fairhurst. All Rights Reserved.
 *
 * Contributor(s): 
 *   IBM Corp.
 *
 */

#define IDC_BASE                        4100

#define IDC_SELECTANCHOR                4100
#define IDC_ARROWSOUTH                  4101
#define IDC_ARROWNORTH                  4102
#define IDC_ARROWEAST                   4103
#define IDC_ARROWWEST                   4104
#define IDC_ARROWSOUTHPLUS              4105
#define IDC_ARROWNORTHPLUS              4106
#define IDC_ARROWEASTPLUS               4107
#define IDC_ARROWWESTPLUS               4108
#define IDC_GRAB                        4109
#define IDC_GRABBING                    4110
#define IDC_CELL                        4111
#define IDC_COPY                        4112
#define IDC_ALIAS                       4113

#define IDC_ARROWWAIT                   4114
#define IDC_CROSS                       4115
#define IDC_HELP                        4116

// OS2TODO HCT temporary bug fix

#ifndef FCF_CLOSEBUTTON // defined in the Merlin toolkit
#define FCF_CLOSEBUTTON 0x04000000L
#endif

==> mozilla-source-1.4.4.tar.bz2: mozilla/widget/src/os2/resource.h <==
/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 *
 * The Original Code is the Mozilla OS/2 libraries.
 *
 * The Initial Developer of the Original Code is John Fairhurst,
 * <john_fairhurst@iname.com>.  Portions created by John Fairhurst are
 * Copyright (C) 1999 John Fairhurst. All Rights Reserved.
 *
 * Contributor(s): 
 *   IBM Corp.
 *
 */

#define IDC_BASE                        4100

#define IDC_SELECTANCHOR                4100
#define IDC_ARROWSOUTH                  4101
#define IDC_ARROWNORTH                  4102
#define IDC_ARROWEAST                   4103
#define IDC_ARROWWEST                   4104
#define IDC_ARROWSOUTHPLUS              4105
#define IDC_ARROWNORTHPLUS              4106
#define IDC_ARROWEASTPLUS               4107
#define IDC_ARROWWESTPLUS               4108
#define IDC_GRAB                        4109
#define IDC_GRABBING                    4110
#define IDC_CELL                        4111
#define IDC_COPY                        4112
#define IDC_ALIAS                       4113
#define IDC_ZOOMIN                      4114
#define IDC_ZOOMOUT                     4115

/* OS/2 specific */
#define IDC_ARROWWAIT                   4116
#define IDC_CROSS                       4117
#define IDC_HELP                        4118

#define IDC_COUNT IDC_HELP-IDC_BASE+1
